cdef class SpellChecker:

    cpdef Sentence spellCheck(self, Sentence sentence):
        """
        The spellCheck method which takes a Sentence as an input.

        PARAMETERS
        ----------
        sentence : Sentence
            Sentence type input.

        RETURNS
        -------
        Sentence
            Sentence result.
        """
        pass



from MorphologicalAnalysis.FsmMorphologicalAnalyzer cimport FsmMorphologicalAnalyzer
from SpellChecker.SpellChecker cimport SpellChecker
from Dictionary.Word cimport Word
from Corpus.Sentence cimport Sentence


cdef class SimpleSpellChecker(SpellChecker):

    cdef FsmMorphologicalAnalyzer fsm

    cpdef list __generateCandidateList(self, str word)
    cpdef list candidateList(self, Word word)
    cpdef Sentence spellCheck(self, Sentence sentence)
